@@ -14,6 +14,7 @@ import subprocess
 import locale
 
 from gi.repository import GObject
+from gi.repository import GLib
 
 import zim.fs
 import zim.errors
@@ -28,7 +29,7 @@ logger = logging.getLogger('zim.applications')
 TEST_MODE = False
 TEST_MODE_RUN_CB = None
 
-_ENCODING = locale.getpreferredencoding(False)
+_ENCODING = locale.getpreferredencoding()
 
 def _decode(data):
 	# Since we do not know for sure what encoding other processes will use
@@ -38,8 +39,6 @@ def _decode(data):
 	except UnicodeDecodeError:
 		return data.decode(_ENCODING)
 
-_ENCODE_UTF8 = _ENCODING in ('ascii', 'us-ascii', 'ANSI_X3.4-1968')
-
 
 _FLATPAK_HOSTCOMMAND_PREFIX = ("flatpak-spawn", "--host")
 
@@ -212,10 +211,6 @@ class Application(object):
 		if hasattr(cwd, 'path'):
 			cwd = cwd.path
 
-		if _ENCODE_UTF8:
-			cwd = cwd.encode('UTF-8') if cwd else cwd
-			argv = [a.encode('UTF-8') for a in argv]
-
 		return cwd, argv
 
 	def run(self, args=None, cwd=None):
@@ -338,13 +333,15 @@ class Application(object):
 		@returns: the PID for the new process
 		'''
 		cwd, argv = self._checkargs(cwd, args)
-		opts = {}
 
 		flags = GObject.SPAWN_SEARCH_PATH
 		if callback:
 			flags |= GObject.SPAWN_DO_NOT_REAP_CHILD
 			# without this flag child is reaped automatically -> no zombies
 
+		if cwd is None:
+			cwd = os.getcwd()
+
 		logger.info('Spawning: %s (cwd: %s)', argv, cwd)
 		if TEST_MODE:
 			TEST_MODE_RUN_CB(argv)
@@ -353,14 +350,14 @@ class Application(object):
 		try:
 			try:
 				pid, stdin, stdout, stderr = \
-					GObject.spawn_async(argv, flags=flags, **opts)
-			except GObject.GError:
+					GObject.spawn_async(argv, flags=flags, working_directory=cwd)
+			except (GObject.GError, GLib.Error):
 				if _CAN_CALL_FLATPAK_HOST_COMMAND:
 					pid, stdin, stdout, stderr = \
-						GObject.spawn_async(_FLATPAK_HOSTCOMMAND_PREFIX + argv, flags=flags, **opts)
+						GObject.spawn_async(_FLATPAK_HOSTCOMMAND_PREFIX + argv, flags=flags, working_directory=cwd)
 				else:
 					raise
-		except GObject.GError:
+		except (GObject.GError, GLib.Error):
 			from zim.gui.widgets import ErrorDialog
 			ErrorDialog(None, _('Failed running: %s') % argv[0]).run()
 				#~ # T: error when application failed to start
