@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 
 # Copyright 2008-2012 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
@@ -40,14 +39,14 @@ def html_encode(text):
 class Dumper(DumperClass):
 
 	TAGS = {
-		EMPHASIS:		('<i>', '</i>'),
-		STRONG: 		('<b>', '</b>'),
-		MARK:			('<u>', '</u>'),
-		STRIKE: 		('<s>', '</s>'),
-		VERBATIM:		('<tt>', '</tt>'),
-		TAG:			('<span class="zim-tag">', '</span>'),
-		SUBSCRIPT:		('<sub>', '</sub>'),
-		SUPERSCRIPT:	('<sup>', '</sup>'),
+		EMPHASIS: ('<i>', '</i>'),
+		STRONG: ('<b>', '</b>'),
+		MARK: ('<u>', '</u>'),
+		STRIKE: ('<s>', '</s>'),
+		VERBATIM: ('<tt>', '</tt>'),
+		TAG: ('<span class="zim-tag">', '</span>'),
+		SUBSCRIPT: ('<sub>', '</sub>'),
+		SUPERSCRIPT: ('<sup>', '</sup>'),
 
 	}
 
@@ -76,7 +75,7 @@ class Dumper(DumperClass):
 
 	def text(self, text):
 		if self.context[-1].tag == FORMATTEDTEXT \
-		and	text.isspace():
+		and text.isspace():
 			# Reduce top level empty lines
 			if self.template_options['empty_lines'] == 'remove':
 				self.context[-1].text.append('\n')
@@ -155,7 +154,7 @@ class Dumper(DumperClass):
 			else:
 				type = '1'
 			return self.dump_block(tag, attrib, strings,
-				_extra='type="%s" start="%s"' % (type, start) )
+				_extra='type="%s" start="%s"' % (type, start))
 		else:
 			return self.dump_block(tag, attrib, strings)
 
@@ -184,13 +183,14 @@ class Dumper(DumperClass):
 		href = self.linker.link(attrib['href'])
 		type = link_type(attrib['href'])
 		if strings:
-			text = u''.join(strings)
+			text = ''.join(strings)
 		else:
 			text = attrib['href']
 		title = text.replace('"', '&quot;')
+		title = re.sub('<.*?>', '', title)
 		return [
 			'<a href="%s" title="%s" class="%s">%s</a>'
-				% (href, title, type, text) ]
+				% (href, title, type, text)]
 
 	def dump_img(self, tag, attrib, strings=None):
 		src = self.linker.img(attrib['src'])
@@ -206,15 +206,16 @@ class Dumper(DumperClass):
 		else:
 			return ['<img src="%s"%s>' % (src, opt)]
 
-	def dump_object(self, *arg, **kwarg):
-		strings = DumperClass.dump_object(self, *arg, **kwarg)
-		strings.insert(0, '<div class="zim-object">\n')
-		strings.append('</div>\n')
+	def dump_object(self, tag, attrib, strings=[]):
+		strings = DumperClass.dump_object(self, tag, attrib, strings)
+		if not attrib['type'].startswith('image+'):
+			strings.insert(0, '<div class="zim-object">\n')
+			strings.append('</div>\n')
 		return strings
 
 	def dump_object_fallback(self, tag, attrib, strings=None):
 		# Fallback to verbatim paragraph
-		return ['<pre>\n'] + map(html_encode, strings) + ['</pre>\n']
+		return ['<pre>\n'] + list(map(html_encode, strings)) + ['</pre>\n']
 
 	def dump_table(self, tag, attrib, strings):
 		aligns = attrib['aligns'].split(',')
