@@ -36,7 +36,12 @@ import os
 import sys
 import logging
 import inspect
-import collections
+
+try:
+	import collections.abc as abc
+except ImportError:
+	# python < version 3.3
+	import collections as abc
 
 from zim.newfs import LocalFolder, LocalFile
 
@@ -321,7 +326,7 @@ class InsertedObjectTypeMap(SignalEmitter):
 			self.emit('changed')
 
 
-class PluginManagerClass(ConnectorMixin, collections.Mapping):
+class PluginManagerClass(ConnectorMixin, abc.Mapping):
 	'''Manager that maintains a set of active plugins
 
 	This class is the interface towards the rest of the application to
@@ -388,7 +393,7 @@ class PluginManagerClass(ConnectorMixin, collections.Mapping):
 		# List "zim.plugins" sub modules based on __path__ because this
 		# parameter determines what folders will considered when importing
 		# sub-modules of the this package once this module is loaded.
-		plugins = set(['arithmetic', 'attachmentbrowser', 'backlinkpane', 'bookmarksbar', 'diagrameditor', 'distractionfree', 'ditaaeditor', 'equationeditor', 'gnu_r_ploteditor', 'gnuplot_ploteditor', 'inlinecalculator', 'insertsymbol', 'journal', 'linesorter', 'linkmap', 'pageindex', 'pathbar', 'printtobrowser', 'quicknote', 'scoreeditor', 'screenshot', 'sequencediagrameditor', 'sourceview', 'spell', 'tableeditor', 'tableofcontents', 'tags', 'tasklist', 'trayicon', 'versioncontrol', 'zeitgeist-logger']) # DEFAULT PLUGINS COMPILED IN BY SETUP.PY
+		plugins = set(['arithmetic', 'attachmentbrowser', 'backlinkpane', 'bookmarksbar', 'diagrameditor', 'distractionfree', 'ditaaeditor', 'equationeditor', 'gnu_r_ploteditor', 'gnuplot_ploteditor', 'inlinecalculator', 'insertsymbol', 'journal', 'linesorter', 'linkmap', 'osx_menubar', 'pageindex', 'pathbar', 'printtobrowser', 'quicknote', 'scoreeditor', 'screenshot', 'sequencediagrameditor', 'sourceview', 'spell', 'tableeditor', 'tableofcontents', 'tags', 'tasklist', 'trayicon', 'versioncontrol', 'zeitgeist-logger']) # DEFAULT PLUGINS COMPILED IN BY SETUP.PY
 		for folder in [f for f in map(LocalFolder, __path__) if f.exists()]:
 			for child in folder:
 				name = child.basename
